@@ -7,35 +7,35 @@ import fnmatch
 from datetime import datetime
 
 import numpy as np
-from sqlalchemy import Float, Table, Column, String, Boolean, Integer, DateTime, ForeignKey
-from sqlalchemy.orm import relationship
+from sqlalchemy import Boolean, Column, DateTime, Float, ForeignKey, Integer, String, Table
 from sqlalchemy.ext.declarative import declarative_base
+from sqlalchemy.orm import relationship
 
 import astropy.table
 from astropy.time import Time
-from astropy.units import Unit, nm, quantity, equivalencies
-
+from astropy.units import Unit, equivalencies, nm, quantity
 
 import sunpy
 from sunpy import config
-from sunpy.time import parse_time
+from sunpy.io import file_tools as sunpy_filetools
+from sunpy.io import fits
 from sunpy.io.header import FileHeader
-from sunpy.io import fits, file_tools as sunpy_filetools
+from sunpy.time import parse_time
 from sunpy.util.types import DatabaseEntryType
 
 TIME_FORMAT = config.get("general", "time_format")
 
 DEFAULT_HEADER = FileHeader([('SIMPLE', True),
-            ('BITPIX', 8),
-            ('NAXIS', 0),
-            ('EXTEND', True),
-            ('COMMENT', ''),
-            ('HISTORY', ''),
-            ('KEYCOMMENTS',
-            {'SIMPLE': 'conforms to FITS standard',
-            'BITPIX': 'array data type',
-            'NAXIS': 'number of array dimensions'}),
-            ('WAVEUNIT', None)])
+                             ('BITPIX', 8),
+                             ('NAXIS', 0),
+                             ('EXTEND', True),
+                             ('COMMENT', ''),
+                             ('HISTORY', ''),
+                             ('KEYCOMMENTS',
+                              {'SIMPLE': 'conforms to FITS standard',
+                               'BITPIX': 'array data type',
+                               'NAXIS': 'number of array dimensions'}),
+                             ('WAVEUNIT', None)])
 
 
 __all__ = [
@@ -286,13 +286,13 @@ class DatabaseEntry(DatabaseEntryType, Base):
 
         Examples
         --------
-        >>> from sunpy.net import vso
+        >>> from sunpy.net import vso, attrs as a
         >>> from sunpy.database.tables import DatabaseEntry
         >>> client = vso.VSOClient()  # doctest: +REMOTE_DATA
         >>> qr = client.search(
-        ...     vso.attrs.Time('2001/1/1', '2001/1/2'),
-        ...     vso.attrs.Instrument('eit'))  # doctest: +REMOTE_DATA
-        >>> entry = DatabaseEntry._from_query_result_block(qr[0])  # doctest: +REMOTE_DATA
+        ...     a.Time('2001/1/1', '2001/1/2'),
+        ...     a.Instrument.eit)  # doctest: +REMOTE_DATA
+        >>> entry = DatabaseEntry._from_query_result_block(qr.blocks[0])  # doctest: +REMOTE_DATA
         >>> entry.source  # doctest: +REMOTE_DATA
         'SOHO'
         >>> entry.provider  # doctest: +REMOTE_DATA
@@ -500,8 +500,8 @@ class DatabaseEntry(DatabaseEntryType, Base):
 def entries_from_query_result(qr, default_waveunit=None):
     """
     Use a query response returned from :meth:`sunpy.net.vso.VSOClient.search`
-    or :meth:`sunpy.net.vso.VSOClient.query_legacy` to generate instances of
-    :class:`DatabaseEntry`. Return an iterator over those instances.
+    to generate instances of :class:`DatabaseEntry`. Return an iterator over
+    those instances.
 
     Parameters
     ----------
@@ -513,12 +513,12 @@ def entries_from_query_result(qr, default_waveunit=None):
 
     Examples
     --------
-    >>> from sunpy.net import vso
+    >>> from sunpy.net import vso, attrs as a
     >>> from sunpy.database.tables import entries_from_query_result
     >>> client = vso.VSOClient()  # doctest: +REMOTE_DATA
     >>> qr = client.search(
-    ...     vso.attrs.Time('2001/1/1', '2001/1/2'),
-    ...     vso.attrs.Instrument('eit'))  # doctest: +REMOTE_DATA
+    ...     a.Time('2001/1/1', '2001/1/2'),
+    ...     a.Instrument.eit)  # doctest: +REMOTE_DATA
     >>> entries = entries_from_query_result(qr)  # doctest: +REMOTE_DATA
     >>> entry = next(entries)  # doctest: +REMOTE_DATA
     >>> entry.source  # doctest: +REMOTE_DATA
