@@ -11,22 +11,35 @@ import configparser
 
 import pytest
 import sqlalchemy
+from parfive.downloader import Downloader
+from parfive.results import Results
 
 from astropy import units
 from astropy.utils.exceptions import AstropyUserWarning
 
 import sunpy
 import sunpy.data.test
-from sunpy.io import fits
-from sunpy.net import Fido, hek, vso
-from sunpy.net import attrs as net_attrs
-from sunpy.database import (Database, NoSuchTagError, EntryNotFoundError, EntryAlreadyAddedError,
-                            TagAlreadyAssignedError, EntryAlreadyStarredError,
-                            EntryAlreadyUnstarredError, attrs, disable_undo, split_database)
-from sunpy.database.tables import Tag, JSONDump, DatabaseEntry, FitsKeyComment, FitsHeaderEntry
-from sunpy.database.caching import LFUCache, LRUCache
-from sunpy.database.commands import NoSuchEntryError, EmptyCommandStackError
 from sunpy.data.test.waveunit import waveunitdir
+from sunpy.database import (
+    Database,
+    EntryAlreadyAddedError,
+    EntryAlreadyStarredError,
+    EntryAlreadyUnstarredError,
+    EntryNotFoundError,
+    NoSuchTagError,
+    TagAlreadyAssignedError,
+    attrs,
+    disable_undo,
+    split_database,
+    tables,
+)
+from sunpy.database.caching import LFUCache, LRUCache
+from sunpy.database.commands import EmptyCommandStackError, NoSuchEntryError
+from sunpy.database.tables import DatabaseEntry, FitsHeaderEntry, FitsKeyComment, JSONDump, Tag
+from sunpy.io import fits
+from sunpy.net import Fido
+from sunpy.net import attrs as net_attrs
+from sunpy.net import hek, vso
 
 testpath = sunpy.data.test.rootdir
 RHESSI_IMAGE = os.path.join(testpath, 'hsi_image_20101016_191218.fits')
@@ -65,37 +78,37 @@ def fido_search_result():
         net_attrs.Instrument('XRS') | net_attrs.Instrument('noaa-indices') |
         net_attrs.Instrument('noaa-predict') |
         (net_attrs.Instrument('norh') & net_attrs.Wavelength(17*units.GHz)) |
-        net_attrs.Instrument('rhessi') |
+        (net_attrs.Instrument('rhessi') & net_attrs.Physobs("summary_lightcurve")) |
         (net_attrs.Instrument('EVE') & net_attrs.Level(0))
-        )
+    )
 
 
 @pytest.fixture
 def query_result():
     return vso.VSOClient().search(
-        vso.attrs.Time('20130801T200000', '20130801T200030'),
-        vso.attrs.Instrument('PLASTIC'))
+        net_attrs.Time('20130801T200000', '20130801T200030'),
+        net_attrs.Instrument('PLASTIC'))
 
 
 @pytest.fixture
 def download_qr():
     return vso.VSOClient().search(
-        vso.attrs.Time('2012-03-29', '2012-03-29'),
-        vso.attrs.Instrument('AIA'))
+        net_attrs.Time('2012-03-29', '2012-03-29'),
+        net_attrs.Instrument('AIA'))
 
 
 @pytest.fixture
 def empty_query():
     return [
-        vso.attrs.Time((2012, 7, 3), (2012, 7, 4)),
-        vso.attrs.Instrument('EIT')]
+        net_attrs.Time((2012, 7, 3), (2012, 7, 4)),
+        net_attrs.Instrument('EIT')]
 
 
 @pytest.fixture
 def download_query():
     return [
-        vso.attrs.Time((2013, 5, 19, 2), (2013, 5, 19, 2), (2013, 5, 19, 2)),
-        vso.attrs.Instrument('VIRGO') | vso.attrs.Instrument('SECCHI')]
+        net_attrs.Time((2013, 5, 19, 2), (2013, 5, 19, 2), (2013, 5, 19, 2)),
+        net_attrs.Instrument('VIRGO') | net_attrs.Instrument('SECCHI')]
 
 
 @pytest.fixture
@@ -441,6 +454,52 @@ def test_add_entry_from_hek_qr(database):
     assert len(database) > 1
 
 
+@pytest.mark.remote_data
+def test_hek_query_download(monkeypatch, database, tmpdir):
+
+    assert len(database) == 0
+
+    records = ['94_1331820530-1331820530', '94_1331820542-1331820542',
+               '94_1331820554-1331820554', '94_1331820566-1331820566',
+               '94_1331820578-1331820578', '94_1331820590-1331820590',
+               '94_1331820602-1331820602', '94_1331820614-1331820614',
+               '94_1331820626-1331820626', '94_1331820638-1331820638']
+
+    def mock_parfive_download(obj, *args, **kwargs):
+
+        assert obj.http_queue.qsize() == 10
+        assert obj.ftp_queue.qsize() == 0
+
+        queue = obj.http_queue
+        obj_records = []
+
+        while not queue.empty():
+            url = queue.get_nowait().keywords['url']
+            obj_records.append(url[-24:])
+
+        assert obj_records == records
+
+        result = Results()
+        result.append(str(tmpdir))
+        return result
+
+    def mock_entries_from_dir(*args, **kwargs):
+        for i in range(10):
+            yield DatabaseEntry()
+
+    monkeypatch.setattr(Downloader, "download", mock_parfive_download)
+    monkeypatch.setattr(tables, "entries_from_dir", mock_entries_from_dir)
+
+    query = hek.HEKClient().search(
+        hek.attrs.Time('2019/03/10 14:40:10', '2019/04/11 16:40:50'),
+        hek.attrs.EventType('FL')
+    )
+
+    database.download_from_hek_query_result(query[4], path=str(tmpdir))
+
+    assert len(database) == 10
+
+
 def num_entries_from_vso_query(db, query, path=None, file_pattern='',
                                overwrite=False):
     db.download_from_vso_query_result(
@@ -584,7 +643,7 @@ def test_add_entries_from_fido_search_result_JSOC_client(database):
         net_attrs.Time('2014-01-01T00:00:00', '2014-01-01T01:00:00'),
         net_attrs.jsoc.Series('hmi.m_45s'),
         net_attrs.jsoc.Notify("sunpy@sunpy.org")
-        )
+    )
     with pytest.raises(ValueError):
         database.add_from_fido_search_result(search_result)
 
@@ -950,8 +1009,8 @@ def test_fetch_separate_filenames():
     db = Database('sqlite:///')
 
     download_query = [
-        vso.attrs.Time('2012-08-05', '2012-08-05 00:00:05'),
-        vso.attrs.Instrument('AIA')
+        net_attrs.Time('2012-08-05', '2012-08-05 00:00:05'),
+        net_attrs.Instrument('AIA')
     ]
 
     tmp_test_dir = os.path.join(
@@ -1045,7 +1104,7 @@ def split_function_database():
 def test_split_database(split_function_database, database):
     # Send all entries with instrument='EIA' to destination_database
     split_function_database, database = split_database(
-        split_function_database, database, vso.attrs.Instrument('EIA'))
+        split_function_database, database, net_attrs.Instrument('EIA'))
 
     observed_source_entries = split_function_database.search(
         vso.attrs.Provider('xyz'), sortby='id')
