@@ -1,4 +1,3 @@
-import warnings
 
 import numpy as np
 
@@ -8,7 +7,6 @@ from astropy.coordinates import SkyCoord
 
 from sunpy.coordinates import frames
 from sunpy.util import MetaDict
-from sunpy.util.exceptions import SunpyUserWarning
 
 __all__ = ['meta_keywords', 'make_fitswcs_header']
 
@@ -39,8 +37,8 @@ def make_fitswcs_header(data, coordinate,
                         instrument=None,
                         telescope=None,
                         observatory=None,
-                        wavelength: u.angstrom=None,
-                        exposure: u.s=None,
+                        wavelength: u.angstrom = None,
+                        exposure: u.s = None,
                         projection_code="TAN"):
     """
     Function to create a FITS-WCS header from a coordinate object
@@ -49,10 +47,11 @@ def make_fitswcs_header(data, coordinate,
 
     Parameters
     ----------
-    data : `~numpy.ndarray`
-        Array data of Map for which a header is required.
-    coordinates : `~astropy.coordinates.SkyCoord` or `~astropy.coordinates.BaseFrame`
-        Coordinate object to get meta information for map header.
+    data : `~numpy.ndarray` or `tuple`
+        Array data of Map for which a header is required, or the shape of the
+        data array (in numpy order, i.e. ``(y_size, x_size)``).
+    coordinate : `~astropy.coordinates.SkyCoord` or `~astropy.coordinates.BaseFrame`
+        The coordinate of the reference pixel.
     reference_pixel :`~astropy.units.Quantity` of size 2, optional
         Reference pixel along each axis. These are expected to be Cartestian ordered, i.e
         the first index is the x axis, second index is the y axis. Defaults to
@@ -117,23 +116,29 @@ def make_fitswcs_header(data, coordinate,
     if isinstance(coordinate, frames.Heliocentric):
         raise ValueError("This function does not currently support heliocentric coordinates.")
 
+    if hasattr(data, "shape"):
+        shape = data.shape
+    else:
+        shape = data
+
     meta_wcs = _get_wcs_meta(coordinate, projection_code)
 
     if hasattr(coordinate, "observer") and isinstance(coordinate.observer, frames.BaseCoordinateFrame):
-        meta_observer = get_observer_meta(coordinate.observer, coordinate.rsun)
+        meta_observer = get_observer_meta(coordinate.observer, getattr(coordinate, 'rsun', None))
         meta_wcs.update(meta_observer)
 
     meta_instrument = _get_instrument_meta(instrument, telescope, observatory, wavelength, exposure)
     meta_wcs.update(meta_instrument)
 
     if reference_pixel is None:
-        reference_pixel = u.Quantity([(data.shape[1] + 1)/2.*u.pixel, (data.shape[0] + 1)/2.*u.pixel])
+        reference_pixel = u.Quantity([(shape[1] - 1)/2.*u.pixel, (shape[0] - 1)/2.*u.pixel])
     if scale is None:
         scale = [1., 1.] * (u.arcsec/u.pixel)
 
-    meta_wcs['crval1'], meta_wcs['crval2'] = (coordinate.spherical.lat.to_value(meta_wcs['cunit1']),
-                                              coordinate.spherical.lon.to_value(meta_wcs['cunit2']))
+    meta_wcs['crval1'], meta_wcs['crval2'] = (coordinate.spherical.lon.to_value(meta_wcs['cunit1']),
+                                              coordinate.spherical.lat.to_value(meta_wcs['cunit2']))
 
+    # Add 1 to go from input 0-based indexing to FITS 1-based indexing
     meta_wcs['crpix1'], meta_wcs['crpix2'] = (reference_pixel[0].to_value(u.pixel) + 1,
                                               reference_pixel[1].to_value(u.pixel) + 1)
 
@@ -190,7 +195,7 @@ def _get_wcs_meta(coordinate, projection_code):
 
 
 @u.quantity_input
-def get_observer_meta(observer, rsun: u.Mm):
+def get_observer_meta(observer, rsun: (u.Mm, None)):
     """
     Function to get observer meta from coordinate frame.
 
@@ -217,8 +222,9 @@ def get_observer_meta(observer, rsun: u.Mm):
     coord_meta['hgln_obs'] = observer.lon.to_value(u.deg)
     coord_meta['hglt_obs'] = observer.lat.to_value(u.deg)
     coord_meta['dsun_obs'] = observer.radius.to_value(u.m)
-    coord_meta['rsun_ref'] = rsun.to_value(u.m)
-    coord_meta['rsun_obs'] = np.arctan(rsun / observer.radius).to_value(u.arcsec)
+    if rsun:
+        coord_meta['rsun_ref'] = rsun.to_value(u.m)
+        coord_meta['rsun_obs'] = np.arctan(rsun / observer.radius).to_value(u.arcsec)
 
     return coord_meta
 
