@@ -1,19 +1,22 @@
 """A Python MapSequence Object"""
-#pylint: disable=W0401,W0614,W0201,W0212,W0404
 
+import html
+import textwrap
+import warnings
+import webbrowser
 from copy import deepcopy
+from tempfile import NamedTemporaryFile
 
-import numpy as np
 import matplotlib.animation
+import numpy as np
 import numpy.ma as ma
 
 import astropy.units as u
 
 from sunpy.map import GenericMap
+from sunpy.util import SunpyUserWarning, expand_list
+from sunpy.visualization import axis_labels_from_ctype, wcsaxes_compat
 from sunpy.visualization.animator.mapsequenceanimator import MapSequenceAnimator
-from sunpy.visualization import wcsaxes_compat
-from sunpy.visualization import axis_labels_from_ctype
-from sunpy.util import expand_list
 
 __all__ = ['MapSequence']
 
@@ -28,8 +31,10 @@ class MapSequence:
     ----------
     args : `list`
         A list of Map instances
-    sortby : `datetime.datetime`
+    sortby : { "date" | `None`}
         Method by which the MapSequence should be sorted along the z-axis.
+        Defaults to sorting by: "date" and is the only supported sorting strategy.
+        Passing `None` will disable sorting.
     derotate : `bool`
         Apply a derotation to the data. Default to False.
 
@@ -48,6 +53,7 @@ class MapSequence:
 
     MapSequences can be co-aligned using the routines in sunpy.image.coalignment.
     """
+
     def __init__(self, *args, sortby='date', derotate=False, **kwargs):
         """Creates a new Map instance"""
 
@@ -81,6 +87,158 @@ class MapSequence:
         """Return the number of maps in a mapsequence."""
         return len(self.maps)
 
+    def __repr__(self):
+        names = set([m.__class__.__name__ for m in self.maps])
+        return (object.__repr__(self) + "\n" +
+                f'MapSequence of {len(self.maps)} elements, with maps from {", ".join(names)}')
+
+    def _repr_html_(self):
+        nmaps = len(self)
+
+        # Output a warning about rendering time if there are more than 9 Maps
+        if nmaps > 9:
+            warnings.warn(f"Rendering the summary for a MapSequence of {nmaps} Maps "
+                          "may take a while.", SunpyUserWarning)
+
+        # Assemble the individual HTML repr from each Map, all hidden initally
+        repr_list = [f"<div style='display: none' index={i}>{m._repr_html_()}</div>"
+                     for i, m in enumerate(self.maps)]
+
+        # Unhide the first Map
+        repr_list_html = "\n".join(repr_list).replace('display: none', 'display: ', 1)
+
+        # Return HTML with Javascript-powered buttons
+        # To avoid potential conflicts, the Javascript code does not use any user-defined functions
+        return textwrap.dedent(f"""\
+            <pre>{html.escape(self.__repr__())}</pre>
+            <form cur_index=0 max_index={nmaps - 1}>
+                <!-- Button to decrement index (always starts disabled) -->
+                <input type=button value='&larr;' style='font-weight: bold' disabled onClick='
+                    var form = this.parentElement;
+
+                    // Decrement index if allowed
+                    var cur_index = Math.max(
+                                        parseInt(form.getAttribute("cur_index")) - 1,
+                                        0
+                                    );
+                    form.setAttribute("cur_index", cur_index);
+
+                    // Enable the decrement button if and only if this is not the first Map
+                    form.children[0].disabled = (cur_index == 0);
+
+                    // Always enable the increment button (because we just decremented)
+                    form.children[1].disabled = false;
+
+                    // Update string (which is children[2] of the form)
+                    form.children[2].innerHTML = "Map at index " + cur_index;
+
+                    // Update visibilities to show only the current index
+                    // This avoids for...of syntax to retain support for ES5 browsers (e.g., IE11)
+                    var array = Array.prototype.slice.call(form.lastElementChild.children);
+                    array.forEach(function (elem)
+                        {{
+                            var form = elem.parentElement.parentElement;
+                            elem.style.display = (elem.getAttribute("index") ==
+                                                      form.getAttribute("cur_index") ? "" : "none"
+                                                 );
+                        }}
+                    );
+                '/>
+
+                <!-- Button to increment index (starts enabled if there is more than one Map) -->
+                <input type=button value='&rarr;' style='font-weight: bold'
+                    {"" if nmaps > 1 else "disabled"} onClick='
+
+                    var form = this.parentElement;
+
+                    // Increment index if allowed
+                    var cur_index = Math.min(
+                                        parseInt(form.getAttribute("cur_index")) + 1,
+                                        form.getAttribute("max_index")
+                                    );
+                    form.setAttribute("cur_index", cur_index);
+
+                    // Always enable the decrement button (because we just incremented)
+                    form.children[0].disabled = false;
+
+                    // Enable the increment button if and only if this is not the last Map
+                    form.children[1].disabled = (cur_index == form.getAttribute("max_index"));
+
+                    // Update string (which is children[2] of the form)
+                    form.children[2].innerHTML = "Map at index " + cur_index;
+
+                    // Update visibilities to show only the current index
+                    // This avoids for...of syntax to retain support for ES5 browsers (e.g., IE11)
+                    var array = Array.prototype.slice.call(form.lastElementChild.children);
+                    array.forEach(function (elem)
+                        {{
+                            var form = elem.parentElement.parentElement;
+                            elem.style.display = (elem.getAttribute("index") ==
+                                                      form.getAttribute("cur_index") ? "" : "none"
+                                                 );
+                        }}
+                    );
+
+                '/>
+
+                <!-- This string is updated as the index is changed -->
+                <span>Map at index 0</span>
+
+                <!-- This element is at the end so that lastElementChild will point to it -->
+                <div>
+                    {repr_list_html}
+                </div>
+            </form>""")
+
+    def quicklook(self):
+        """
+        Display a quicklook summary of the MapSequence instance using the default web browser.
+
+        Click on the |larr| and |rarr| buttons to step through the individual maps.
+
+        .. |larr|   unicode:: U+02190 .. LEFTWARDS ARROW
+        .. |rarr|   unicode:: U+02192 .. RIGHTWARDS ARROW
+
+        Notes
+        -----
+        The image colormap uses
+        `histogram equalization <https://en.wikipedia.org/wiki/Histogram_equalization>`__.
+
+        Interactive elements require Javascript support to be enabled in the web browser.
+
+        Examples
+        --------
+        >>> from sunpy.map import Map
+        >>> import sunpy.data.sample  # doctest: +REMOTE_DATA
+        >>> seq = Map(sunpy.data.sample.HMI_LOS_IMAGE,
+        ...           sunpy.data.sample.AIA_1600_IMAGE,
+        ...           sunpy.data.sample.EIT_195_IMAGE,
+        ...           sequence=True)  # doctest: +REMOTE_DATA
+        >>> seq.quicklook()  # doctest: +SKIP
+
+        (which will open the following content in the default web browser)
+
+        .. generate:: html
+            :html_border:
+
+            from sunpy.map import Map
+            import sunpy.data.sample
+            seq = Map(sunpy.data.sample.HMI_LOS_IMAGE,
+                      sunpy.data.sample.AIA_1600_IMAGE,
+                      sunpy.data.sample.EIT_195_IMAGE,
+                      sequence=True)
+            print(seq._repr_html_())
+
+        """
+        with NamedTemporaryFile('w', delete=False, prefix='sunpy.map.', suffix='.html') as f:
+            url = 'file://' + f.name
+            f.write(textwrap.dedent(f"""\
+                <html>
+                    <title>Quicklook summary for {html.escape(object.__repr__(self))}</title>
+                    <body>{self._repr_html_()}</body>
+                </html>"""))
+        webbrowser.open_new_tab(url)
+
     # Sorting methods
     @classmethod
     def _sort_by_date(cls):
@@ -88,7 +246,7 @@ class MapSequence:
 
     def _derotate(self):
         """Derotates the layers in the MapSequence"""
-        pass
+        raise NotImplementedError("This functionality has not yet been implemented.")
 
     def plot(self, axes=None, resample=None, annotate=True,
              interval=200, plot_function=None, **kwargs):
@@ -160,7 +318,7 @@ class MapSequence:
         fig = axes.get_figure()
 
         if not plot_function:
-            plot_function = lambda fig, ax, smap: []
+            def plot_function(fig, ax, smap): return []
         removes = []
 
         # Normal plot
@@ -326,7 +484,8 @@ class MapSequence:
         If all the map shapes are not the same, a ValueError is thrown.
         """
         if self.all_maps_same_shape():
-            data = np.swapaxes(np.swapaxes(np.asarray([m.data for m in self.maps]), 0, 1).copy(), 1, 2).copy()
+            data = np.swapaxes(np.swapaxes(np.asarray(
+                [m.data for m in self.maps]), 0, 1).copy(), 1, 2).copy()
             if self.at_least_one_map_has_mask():
                 mask_sequence = np.zeros_like(data, dtype=bool)
                 for im, m in enumerate(self.maps):
