@@ -10,20 +10,18 @@ This module provides the `Fido
 """
 import os
 from pathlib import Path
+from textwrap import dedent
 from collections.abc import Sequence
 
 from parfive import Downloader, Results
 
-from sunpy.util.datatype_factory_base import BasicRegistrationFactory
-from sunpy.util.datatype_factory_base import NoMatchError
-from sunpy.util.datatype_factory_base import MultipleMatchError
+from astropy.table import Table
 
-from sunpy.net.base_client import BaseClient
-from sunpy.net.dataretriever.client import QueryResponse
-from sunpy.net.vso import VSOClient, QueryResponse as vsoQueryResponse
-
-from sunpy.net import attr
-from sunpy.net import attrs as a
+from sunpy.net import attr, vso
+from sunpy.net.base_client import BaseClient, BaseQueryResponse
+from sunpy.util.datatype_factory_base import BasicRegistrationFactory, NoMatchError
+from sunpy.util.parfive_helpers import Downloader, Results
+from sunpy.util.util import get_width
 
 __all__ = ['Fido', 'UnifiedResponse', 'UnifiedDownloaderFactory']
 
@@ -41,39 +39,22 @@ class UnifiedResponse(Sequence):
     index the second dimension with ``::2``.
     """
 
-    def __init__(self, lst):
+    def __init__(self, *results):
         """
         Parameters
         ----------
-        lst : `object`
-            A single instance or an iterable of ``(QueryResponse, client)``
-            pairs or ``QueryResponse`` objects with a ``.client`` attribute.
+        results : `sunpy.net.base_client.BaseQueryResponse`
+            One or more QueryResponse objects.
         """
-
-        tmplst = []
-        # numfile is the number of files not the number of results.
+        self._list = []
         self._numfile = 0
-        if isinstance(lst, (QueryResponse, vsoQueryResponse)):
-            if not hasattr(lst, 'client'):
-                raise ValueError(
-                    ("A {} object is only a valid input to UnifiedResponse "
-                     "if it has a client attribute.").
-                    format(type(lst).__name__))
-            tmplst.append(lst)
-            self._numfile = len(lst)
-        else:
-            for block in lst:
-                if isinstance(block, tuple) and len(block) == 2:
-                    block[0].client = block[1]
-                    tmplst.append(block[0])
-                    self._numfile += len(block[0])
-                elif hasattr(block, 'client'):
-                    tmplst.append(block)
-                    self._numfile += len(block)
-                else:
-                    raise ValueError(
-                        "{} is not a valid input to UnifiedResponse.".format(type(lst)))
-        self._list = tmplst
+        for result in results:
+            if not isinstance(result, BaseQueryResponse):
+                raise TypeError(
+                    f"{type(result)} is not derived from sunpy.net.base_client.BaseQueryResponse")
+
+            self._list.append(result)
+            self._numfile = len(result)
 
     def __len__(self):
         return len(self._list)
@@ -81,28 +62,6 @@ class UnifiedResponse(Sequence):
     def __iter__(self):
         return self.responses
 
-    def _handle_record_slice(self, client_resp, record_slice):
-        """
-        Given a slice to be applied to the results from a single client, return
-        an object of the same type as client_resp.
-        """
-        # When we subindex, we want to persist the type of the response object.
-        resp_type = type(client_resp)
-
-        # Make sure we always have an iterable, as most of the response objects
-        # expect one.
-        if isinstance(record_slice, int):
-            resp = [client_resp[record_slice]]
-        else:
-            resp = client_resp[record_slice]
-
-        # Reconstruct a response object with the sub-indexed records.
-        ret = resp_type(resp)
-        # Make sure we pass the client back out again.
-        ret.client = client_resp.client
-
-        return ret
-
     def __getitem__(self, aslice):
         """
         Support slicing the UnifiedResponse as a 2D object.
@@ -111,7 +70,11 @@ class UnifiedResponse(Sequence):
         returned from those clients.
         """
         # Just a single int as a slice, we are just indexing client.
-        if isinstance(aslice, (int, slice)):
+        # Convert it to a slice so we still return a list.
+        if isinstance(aslice, int):
+            aslice = slice(aslice, aslice + 1)
+
+        if isinstance(aslice, slice):
             ret = self._list[aslice]
 
         # Make sure we only have a length two slice.
@@ -123,20 +86,19 @@ class UnifiedResponse(Sequence):
             # Indexing both client and records, but only for one client.
             if isinstance(aslice[0], int):
                 client_resp = self._list[aslice[0]]
-                ret = self._handle_record_slice(client_resp, aslice[1])
+                ret = [client_resp[aslice[1]]]
 
             # Indexing both client and records for multiple clients.
             else:
                 intermediate = self._list[aslice[0]]
                 ret = []
                 for client_resp in intermediate:
-                    resp = self._handle_record_slice(client_resp, aslice[1])
-                    ret.append(resp)
+                    ret.append(client_resp[aslice[1]])
 
         else:
             raise IndexError("UnifiedResponse objects must be sliced with integers.")
 
-        return UnifiedResponse(ret)
+        return UnifiedResponse(*ret)
 
     def get_response(self, i):
         """
@@ -146,7 +108,7 @@ class UnifiedResponse(Sequence):
 
     def response_block_properties(self):
         """
-        Returns a set of class attributes on all the response blocks.
+        A set of class attributes on all the response blocks.
 
         Returns
         -------
@@ -158,6 +120,27 @@ class UnifiedResponse(Sequence):
             s.intersection(self.get_response(i).response_block_properties())
         return s
 
+    @property
+    def tables(self):
+        """
+        Returns a list of `astropy.table.Table` for all responses present in a specific
+        `~sunpy.net.fido_factory.UnifiedResponse` object. They can then be used
+        to perform key-based indexing of objects of either type
+        `sunpy.net.dataretriever.client.QueryResponse`, `sunpy.net.vso.QueryResponse` or
+        `sunpy.net.jsoc.JSOCClient`
+
+        Returns
+        -------
+        `list`
+            A list of `astropy.table.Table`, consisting of data either from the
+            `sunpy.net.dataretriever.client.QueryResponse`, `sunpy.net.vso.QueryResponse` or
+            `sunpy.net.jsoc.JSOCClient`.
+        """
+        tables = []
+        for block in self.responses:
+            tables.append(block.build_table())
+        return tables
+
     @property
     def responses(self):
         """
@@ -187,10 +170,7 @@ class UnifiedResponse(Sequence):
         return ret
 
     def __repr__(self):
-        ret = super().__repr__()
-        ret += '\n' + str(self)
-
-        return ret
+        return object.__repr__(self) + "\n" + str(self)
 
     def __str__(self):
         nprov = len(self)
@@ -207,46 +187,42 @@ class UnifiedResponse(Sequence):
         return ret
 
 
-"""
-Construct a simple AttrWalker to split up searches into blocks of attrs being
-'anded' with AttrAnd.
-
-This pipeline only understands AttrAnd and AttrOr, Fido.search passes in an
-AttrAnd object of all the query parameters, if an AttrOr is encountered the
-query is split into the component parts of the OR, which at somepoint will end
-up being an AttrAnd object, at which point it is passed into
-_get_registered_widget.
-"""
 query_walker = attr.AttrWalker()
+"""
+We construct an `AttrWalker` which calls `_make_query_to_client` for each
+logical component of the query, i.e. any block which are ANDed together.
+"""
+
+
+@query_walker.add_creator(attr.DataAttr)
+def _create_data(walker, query, factory):
+    return factory._make_query_to_client(query)
 
 
 @query_walker.add_creator(attr.AttrAnd)
 def _create_and(walker, query, factory):
-    is_time = any([isinstance(x, a.Time) for x in query.attrs])
-    if not is_time:
-        error = "The following part of the query did not have a time specified:\n"
-        for at in query.attrs:
-            error += str(at) + ', '
-        raise ValueError(error)
-
-    # Return the response and the client
-    return [factory._make_query_to_client(*query.attrs)]
+    return factory._make_query_to_client(*query.attrs)
 
 
 @query_walker.add_creator(attr.AttrOr)
 def _create_or(walker, query, factory):
     qblocks = []
     for attrblock in query.attrs:
-        qblocks.extend(walker.create(attr.and_(attrblock), factory))
+        qblocks += walker.create(attrblock, factory)
 
     return qblocks
 
 
 class UnifiedDownloaderFactory(BasicRegistrationFactory):
     """
-    sunpy.net.Fido(\\*args, \\*\\*kwargs)
+    Fido is a unified data search and retrieval tool.
+
+    It provides simultaneous access to a variety of online data sources, some
+    cover multiple instruments and data products like the Virtual Solar
+    Observatory and some are specific to a single source.
+
+    For details of using `~sunpy.net.Fido` see :ref:`fido_guide`.
 
-    Search and Download data from a variety of supported sources.
     """
 
     def search(self, *query):
@@ -259,21 +235,21 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
 
         >>> from sunpy.net import Fido, attrs as a
         >>> import astropy.units as u
-        >>> unifresp = Fido.search(a.Time('2012/3/4', '2012/3/6'), a.Instrument('lyra')) # doctest: +REMOTE_DATA
+        >>> unifresp = Fido.search(a.Time('2012/3/4', '2012/3/6'), a.Instrument.lyra) # doctest: +REMOTE_DATA
 
         Query for data from Nobeyama Radioheliograph and RHESSI
 
         >>> unifresp = Fido.search(a.Time('2012/3/4', '2012/3/6'),
-        ...     (a.Instrument('norh') & a.Wavelength(17*u.GHz)) | a.Instrument('rhessi'))  # doctest: +REMOTE_DATA
+        ...     (a.Instrument.norh & a.Wavelength(17*u.GHz)) | a.Instrument.rhessi)  # doctest: +REMOTE_DATA
 
         Query for 304 Angstrom SDO AIA data with a cadence of 10 minutes
 
         >>> import astropy.units as u
         >>> from sunpy.net import Fido, attrs as a
         >>> unifresp = Fido.search(a.Time('2012/3/4', '2012/3/6'),
-        ...                        a.Instrument('AIA'),
+        ...                        a.Instrument.aia,
         ...                        a.Wavelength(304*u.angstrom, 304*u.angstrom),
-        ...                        a.vso.Sample(10*u.minute))  # doctest: +REMOTE_DATA
+        ...                        a.Sample(10*u.minute))  # doctest: +REMOTE_DATA
 
         Parameters
         ----------
@@ -294,9 +270,21 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         ie. query is now of form A & B or ((A & B) | (C & D))
         This helps in modularising query into parts and handling each of the
         parts individually.
-        """  # noqa
+        """
         query = attr.and_(*query)
-        return UnifiedResponse(query_walker.create(query, self))
+        results = query_walker.create(query, self)
+
+        # If we have searched the VSO but no results were returned, but another
+        # client generated results, we drop the empty VSO results for tidiness.
+        # This is because the VSO _can_handle_query is very broad because we
+        # don't know the full list of supported values we can search for (yet).
+        if len(results) > 1:
+            vso_results = list(filter(lambda r: isinstance(r, vso.QueryResponse), results))
+            for vres in vso_results:
+                if len(vres) == 0:
+                    results.remove(vres)
+
+        return UnifiedResponse(*results)
 
     def fetch(self, *query_results, path=None, max_conn=5, progress=True,
               overwrite=False, downloader=None, **kwargs):
@@ -308,27 +296,22 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         ----------
         query_results : `sunpy.net.fido_factory.UnifiedResponse`
             Container returned by query method, or multiple.
-
         path : `str`
             The directory to retrieve the files into. Can refer to any fields
             in `UnifiedResponse.response_block_properties` via string formatting,
             moreover the file-name of the file downloaded can be referred to as file,
             e.g. "{source}/{instrument}/{time.start}/{file}".
-
         max_conn : `int`, optional
             The number of parallel download slots.
-
         progress : `bool`, optional
             If `True` show a progress bar showing how many of the total files
             have been downloaded. If `False`, no progress bars will be shown at all.
-
         overwrite : `bool` or `str`, optional
             Determine how to handle downloading if a file already exists with the
             same name. If `False` the file download will be skipped and the path
             returned to the existing file, if `True` the file will be downloaded
             and the existing file will be overwritten, if `'unique'` the filename
             will be modified to be unique.
-
         downloader : `parfive.Downloader`, optional
             The download manager to use. If specified the ``max_conn``,
             ``progress`` and ``overwrite`` arguments are ignored.
@@ -339,7 +322,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
 
         Examples
         --------
-        >>> from sunpy.net.vso.attrs import Time, Instrument
+        >>> from sunpy.net.attrs import Time, Instrument
         >>> unifresp = Fido.search(Time('2012/3/4','2012/3/5'), Instrument('EIT'))  # doctest: +REMOTE_DATA
         >>> filepaths = Fido.fetch(unifresp)  # doctest: +SKIP
 
@@ -349,7 +332,8 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
 
         """
         if path is not None:
-            exists = list(filter(lambda p: p.exists(), Path(path).parents))
+            exists = list(filter(lambda p: p.exists(), Path(path).resolve().parents))
+
             if not os.access(exists[0], os.W_OK):
                 raise PermissionError('You do not have permission to write'
                                       f' to the directory {exists[0]}.')
@@ -404,7 +388,6 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         """Factory helper function"""
         candidate_widget_types = list()
         for key in self.registry:
-
             if self.registry[key](*args):
                 candidate_widget_types.append(key)
 
@@ -412,18 +395,6 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         if n_matches == 0:
             # There is no default client
             raise NoMatchError("This query was not understood by any clients. Did you miss an OR?")
-        elif n_matches == 2:
-            # If two clients have reported they understand this query, and one
-            # of them is the VSOClient, then we ignore VSOClient.
-            if VSOClient in candidate_widget_types:
-                candidate_widget_types.remove(VSOClient)
-
-        # Finally check that we only have one match.
-        if len(candidate_widget_types) > 1:
-            candidate_names = [cls.__name__ for cls in candidate_widget_types]
-            raise MultipleMatchError("The following clients matched this query. "
-                                     "Please make your query more specific.\n"
-                                     "{}".format(candidate_names))
 
         return candidate_widget_types
 
@@ -437,14 +408,48 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
 
         Returns
         -------
-        response : `~sunpy.net.dataretriever.client.QueryResponse`
+        results : `list`
 
         client : `object`
             Instance of client class
         """
         candidate_widget_types = self._check_registered_widgets(*query)
-        tmpclient = candidate_widget_types[0]()
-        return tmpclient.search(*query), tmpclient
+        results = []
+        for client in candidate_widget_types:
+            tmpclient = client()
+            results.append(tmpclient.search(*query))
+
+        # This method is called by `search` and the results are fed into a
+        # UnifiedResponse object.
+        return results
+
+    def __repr__(self):
+        return object.__repr__(self) + "\n" + str(self)
+
+    def __str__(self):
+        """
+        This enables the "pretty" printing of the Fido Clients.
+        """
+        return self._print_clients()
+
+    def _repr_html_(self):
+        """
+        This enables the "pretty" printing of the Fido Clients with html.
+        """
+        return self._print_clients(html=True)
+
+    def _print_clients(self, html=False) -> str:
+        width = -1 if html else get_width()
+
+        t = Table(names=["Client", "Description"], dtype=["U80", "U120"])
+        lines = ["sunpy.net.Fido", dedent(self.__doc__)]
+        if html:
+            lines = [f"<p>{line}</p>" for line in lines]
+        for key in BaseClient._registry.keys():
+            t.add_row((key.__name__, dedent(
+                key.__doc__.partition("\n\n")[0].replace("\n    ", " "))))
+        lines.extend(t.pformat_all(show_dtype=False, max_width=width, align="<", html=html))
+        return '\n'.join(lines)
 
 
 Fido = UnifiedDownloaderFactory(
