@@ -7,9 +7,16 @@ import astropy.units as u
 from astropy.coordinates import BaseCoordinateFrame, Longitude, SkyCoord, get_body
 from astropy.time import TimeDelta
 
-from sunpy.coordinates import HeliographicStonyhurst, Helioprojective, Heliocentric
-from sunpy.map import (all_coordinates_from_map, contains_full_disk, coordinate_is_on_solar_disk,
-                       is_all_off_disk, is_all_on_disk, map_edges, on_disk_bounding_coordinates)
+from sunpy.coordinates import Heliocentric, HeliographicStonyhurst, Helioprojective
+from sunpy.map import (
+    all_coordinates_from_map,
+    contains_full_disk,
+    coordinate_is_on_solar_disk,
+    is_all_off_disk,
+    is_all_on_disk,
+    map_edges,
+    on_disk_bounding_coordinates,
+)
 from sunpy.map.header_helper import get_observer_meta
 from sunpy.time import parse_time
 from sunpy.util import expand_list
@@ -83,7 +90,7 @@ def diff_rot(duration: u.s, latitude: u.deg, rot_type='howard', frame_time='side
 
     if rot_type not in ['howard', 'allen', 'snodgrass']:
         raise ValueError("rot_type must equal one of "
-                          "{{ {} }}".format(" | ".join(rot_params.keys())))
+                         "{{ {} }}".format(" | ".join(rot_params.keys())))
 
     A, B, C = rot_params[rot_type]
 
@@ -140,7 +147,8 @@ def _get_new_observer(initial_obstime, observer, time):
     """
     # Check the input and create the new observer
     if (observer is not None) and (time is not None):
-        raise ValueError("Either the 'observer' or the 'time' keyword must be specified, but not both simultaneously.")
+        raise ValueError(
+            "Either the 'observer' or the 'time' keyword must be specified, but not both simultaneously.")
     elif observer is not None:
         # Check that the new_observer is specified correctly.
         if not (isinstance(observer, (BaseCoordinateFrame, SkyCoord))):
@@ -220,8 +228,9 @@ def solar_rotate_coordinate(coordinate, observer=None, time=None, **diff_rot_kwa
     >>> from sunpy.time import parse_time
     >>> start_time = parse_time('2010-09-10 12:34:56')
     >>> end_time = parse_time('2010-09-11 13:34:56')
-    >>> c = SkyCoord(-570*u.arcsec, 120*u.arcsec, obstime=start_time, frame=Helioprojective)
-    >>> solar_rotate_coordinate(c, time=end_time)
+    >>> c = SkyCoord(-570*u.arcsec, 120*u.arcsec, obstime=start_time,
+    ...              observer="earth", frame=Helioprojective)
+    >>> solar_rotate_coordinate(c, time=end_time)  # doctest: +IGNORE_WARNINGS
     <SkyCoord (Helioprojective: obstime=2010-09-11T13:34:56.000, rsun=695700.0 km, observer=<HeliographicStonyhurst Coordinate (obstime=2010-09-11T13:34:56.000): (lon, lat, radius) in (deg, deg, AU)
         (9.40248797e-16, 7.24318962, 1.00669016)>): (Tx, Ty, distance) in (arcsec, arcsec, AU)
         (-363.04027419, 104.87807178, 1.00241935)>
@@ -241,25 +250,28 @@ def solar_rotate_coordinate(coordinate, observer=None, time=None, **diff_rot_kwa
     # Calculate the interval between the start and end time
     interval = (new_observer.obstime - coordinate.obstime).to(u.s)
 
-    # Compute Stonyhurst Heliographic co-ordinates - returns (longitude,
-    # latitude). Points off the limb are returned as nan.
-    heliographic_coordinate = coordinate.transform_to(HeliographicStonyhurst)
+    # Ignore some invalid NaN comparisions within astropy
+    # (fixed in astropy 4.0.1 https://github.com/astropy/astropy/pull/9843)
+    with np.errstate(invalid='ignore'):
+        # Compute Stonyhurst Heliographic co-ordinates - returns (longitude,
+        # latitude). Points off the limb are returned as nan.
+        heliographic_coordinate = coordinate.transform_to(HeliographicStonyhurst)
 
-    # Compute the differential rotation
-    drot = diff_rot(interval, heliographic_coordinate.lat.to(u.degree), **diff_rot_kwargs)
+        # Compute the differential rotation
+        drot = diff_rot(interval, heliographic_coordinate.lat.to(u.degree), **diff_rot_kwargs)
 
-    # Rotate the input co-ordinate as seen by the original observer
-    heliographic_rotated = SkyCoord(heliographic_coordinate.lon + drot,
-                                    heliographic_coordinate.lat,
-                                    heliographic_coordinate.radius,
-                                    obstime=new_observer.obstime,
-                                    observer=new_observer,
-                                    frame=HeliographicStonyhurst)
+        # Rotate the input co-ordinate as seen by the original observer
+        heliographic_rotated = SkyCoord(heliographic_coordinate.lon + drot,
+                                        heliographic_coordinate.lat,
+                                        heliographic_coordinate.radius,
+                                        obstime=new_observer.obstime,
+                                        observer=new_observer,
+                                        frame=HeliographicStonyhurst)
 
-    # Calculate where the rotated co-ordinate appears as seen by new observer,
-    # and then transform it into the co-ordinate system of the input
-    # co-ordinate.
-    return heliographic_rotated.transform_to(coordinate.frame.name)
+        # Calculate where the rotated co-ordinate appears as seen by new observer,
+        # and then transform it into the co-ordinate system of the input
+        # co-ordinate.
+        return heliographic_rotated.transform_to(coordinate.frame.name)
 
 
 def _rotate_submap_edge(smap, pixels, observer, **diff_rot_kwargs):
@@ -356,7 +368,7 @@ def _get_bounding_coordinates(coords):
     rotated_y_max = _get_extreme_position(coords, "Ty", operator=np.nanmax)
     return SkyCoord([rotated_x_min, rotated_x_max] * u.arcsec,
                     [rotated_y_min, rotated_y_max] * u.arcsec,
-                    frame=Helioprojective, observer=coords[0].observer)
+                    frame=coords[0].frame)
 
 
 def _warp_sun_coordinates(xy, smap, new_observer, **diff_rot_kwargs):
@@ -408,7 +420,8 @@ def _warp_sun_coordinates(xy, smap, new_observer, **diff_rot_kwargs):
 
         heliographic_coordinate = output_hpc_coords.transform_to(HeliographicStonyhurst)
         # Now transform the HGS coordinates to the obstime of the input map (to account for movement of Earth)
-        heliographic_coordinate = heliographic_coordinate.transform_to(HeliographicStonyhurst(obstime=smap.date))
+        heliographic_coordinate = heliographic_coordinate.transform_to(
+            HeliographicStonyhurst(obstime=smap.date))
 
         # Compute the differential rotation.
         drot = diff_rot(interval, heliographic_coordinate.lat.to(u.degree), **diff_rot_kwargs)
@@ -518,7 +531,7 @@ def differential_rotate(smap, observer=None, time=None, **diff_rot_kwargs):
 
             # Create a submap that excludes the off disk emission that does
             # not need to be rotated.
-            smap = smap.submap(bottom_left, top_right)
+            smap = smap.submap(bottom_left, top_right=top_right)
         bottom_left = smap.bottom_left_coord
         top_right = smap.top_right_coord
 
@@ -528,25 +541,30 @@ def differential_rotate(smap, observer=None, time=None, **diff_rot_kwargs):
         # Calculate where the output array moves to.
         # Rotate the top and bottom edges
         rotated_top = _rotate_submap_edge(smap, edges[0], observer=new_observer, **diff_rot_kwargs)
-        rotated_bottom = _rotate_submap_edge(smap, edges[1], observer=new_observer, **diff_rot_kwargs)
+        rotated_bottom = _rotate_submap_edge(
+            smap, edges[1], observer=new_observer, **diff_rot_kwargs)
 
         # Rotate the left and right hand edges
         rotated_lhs = _rotate_submap_edge(smap, edges[2], observer=new_observer, **diff_rot_kwargs)
         rotated_rhs = _rotate_submap_edge(smap, edges[3], observer=new_observer, **diff_rot_kwargs)
 
         # Calculate the bounding box of the rotated map
-        rotated_bl, rotated_tr = _get_bounding_coordinates([rotated_top, rotated_bottom, rotated_lhs, rotated_rhs])
+        rotated_bl, rotated_tr = _get_bounding_coordinates(
+            [rotated_top, rotated_bottom, rotated_lhs, rotated_rhs])
 
         # Calculate the maximum distance in pixels the map has moved by comparing
         # how far the original and rotated bounding boxes have moved.
-        diff_x = [(np.abs(rotated_bl.Tx - bottom_left.Tx)).value, (np.abs(rotated_tr.Tx - top_right.Tx)).value]
+        diff_x = [(np.abs(rotated_bl.Tx - bottom_left.Tx)).value,
+                  (np.abs(rotated_tr.Tx - top_right.Tx)).value]
         deltax = int(np.ceil(np.max(diff_x) / smap.scale.axis1).value)
 
-        diff_y = [(np.abs(rotated_bl.Ty - bottom_left.Ty)).value, (np.abs(rotated_tr.Ty - top_right.Ty)).value]
+        diff_y = [(np.abs(rotated_bl.Ty - bottom_left.Ty)).value,
+                  (np.abs(rotated_tr.Ty - top_right.Ty)).value]
         deltay = int(np.ceil(np.max(diff_y) / smap.scale.axis2).value)
 
         # Create a new `smap` with the padding around it
-        padded_data = np.pad(smap.data, ((deltay, deltay), (deltax, deltax)), 'constant', constant_values=0)
+        padded_data = np.pad(smap.data, ((deltay, deltay), (deltax, deltax)),
+                             'constant', constant_values=0)
         padded_meta = deepcopy(smap.meta)
         padded_meta['naxis2'], padded_meta['naxis1'] = smap.data.shape
 
@@ -589,11 +607,14 @@ def differential_rotate(smap, observer=None, time=None, **diff_rot_kwargs):
         # Define a new reference pixel and the value at the reference pixel.
         # Note that according to the FITS convention the first pixel in the
         # image is at (1.0, 1.0).
-        center_rotated = solar_rotate_coordinate(smap.center, observer=new_observer, **diff_rot_kwargs)
+        center_rotated = solar_rotate_coordinate(
+            smap.center, observer=new_observer, **diff_rot_kwargs)
         out_meta['crval1'] = center_rotated.Tx.value
         out_meta['crval2'] = center_rotated.Ty.value
-        out_meta['crpix1'] = 1 + smap.data.shape[1]/2.0 + ((center_rotated.Tx - smap.center.Tx)/smap.scale.axis1).value
-        out_meta['crpix2'] = 1 + smap.data.shape[0]/2.0 + ((center_rotated.Ty - smap.center.Ty)/smap.scale.axis2).value
-        return smap._new_instance(out_data, out_meta).submap(rotated_bl, rotated_tr)
+        out_meta['crpix1'] = 1 + smap.data.shape[1]/2.0 + \
+            ((center_rotated.Tx - smap.center.Tx)/smap.scale.axis1).value
+        out_meta['crpix2'] = 1 + smap.data.shape[0]/2.0 + \
+            ((center_rotated.Ty - smap.center.Ty)/smap.scale.axis2).value
+        return smap._new_instance(out_data, out_meta).submap(rotated_bl, top_right=rotated_tr)
     else:
         return smap._new_instance(out_data, out_meta)
