@@ -13,7 +13,7 @@ import astropy.units as u
 from astropy.time import Time
 
 # This is not called but imported to register it
-from sunpy.time.utime import TimeUTime  # noqa
+from sunpy.time.utime import TimeUTime  # NOQA
 from sunpy.util.decorators import add_common_docstring
 
 __all__ = [
@@ -234,9 +234,11 @@ def _variables_for_parse_time_docstring():
     # Do Builtins
     types2 = [t.__qualname__ for t in types if t.__module__ == "builtins"]
     # # Do all the non-special ones where we take the package name and the class
-    types2 += [t.__module__.split(".")[0] + "." + t.__qualname__ for t in types if not t.__module__.startswith(("builtins", "astropy"))]
+    types2 += [t.__module__.split(".")[0] + "." +
+               t.__qualname__ for t in types if not t.__module__.startswith(("builtins", "astropy"))]
     # Special case astropy.time where we need the subpackage
-    types2 += ["astropy.time." + t.__qualname__ for t in types if t.__module__.startswith("astropy.time")]
+    types2 += ["astropy.time." +
+               t.__qualname__ for t in types if t.__module__.startswith("astropy.time")]
     parse_time_types = str(types2)[1:-1].replace("'", "`")
     ret['parse_time_types'] = parse_time_types
     ret['parse_time_desc'] = """
