@@ -6,7 +6,6 @@ import copy
 import warnings
 from collections import OrderedDict
 
-import matplotlib.pyplot as plt
 import pandas as pd
 
 import astropy
@@ -46,8 +45,6 @@ class GenericTimeSeries:
 
     Attributes
     ----------
-    data : `~pandas.DataFrame`
-        A `pandas.DataFrame` representing one or more fields as a function of time.
     meta : `~sunpy.timeseries.metadata.TimeSeriesMetaData`
         The metadata giving details about the time series data/instrument.
     units : `dict`
@@ -58,6 +55,7 @@ class GenericTimeSeries:
     >>> from sunpy.timeseries import TimeSeries
     >>> from sunpy.time import parse_time
     >>> from astropy.time import TimeDelta
+    >>> import astropy.units as u
     >>> import numpy as np
     >>> import pandas as pd
     >>> times = parse_time("now") - TimeDelta(np.arange(24 * 60)*u.minute)
@@ -91,18 +89,18 @@ class GenericTimeSeries:
 
     # kwargs are not used here but are passed in for sources.
     def __init__(self, data, meta=None, units=None, **kwargs):
-        self.data = data
+        self._data = data
         tr = self.time_range
         # Check metadata input
         if meta is None:
             # No meta given, so default
-            self.meta = TimeSeriesMetaData(MetaDict(), tr, list(self.data.columns.values))
+            self.meta = TimeSeriesMetaData(MetaDict(), tr, list(self._data.columns.values))
         elif isinstance(meta, (dict, OrderedDict, MetaDict)):
             # Given the values for metadata (dict) and infer timerange and colnames from the data
-            self.meta = TimeSeriesMetaData(meta, tr, list(self.data.columns.values))
+            self.meta = TimeSeriesMetaData(meta, tr, list(self._data.columns.values))
         elif isinstance(meta, tuple):
             # Given the values all in a tuple
-            self.meta = TimeSeriesMetaData(meta, tr, list(self.data.columns.values))
+            self.meta = TimeSeriesMetaData(meta, tr, list(self._data.columns.values))
         else:
             # Should have a list of 3-tuples giving a complex metadata list.
             self.meta = meta
@@ -119,6 +117,19 @@ class GenericTimeSeries:
 
 # #### Attribute definitions #### #
 
+    @property
+    def data(self):
+        """
+        A `pandas.DataFrame` representing one or more fields as a function of time.
+        """
+        warnings.warn("Using .data to access the dataframe is discouraged; "
+                      "use .to_dataframe() instead.", SunpyUserWarning)
+        return self._data
+
+    @data.setter
+    def data(self, d):
+        self._data = d
+
     @property
     def source(self):
         """
@@ -131,22 +142,29 @@ class GenericTimeSeries:
         """
         A list of all the names of the columns in the data.
         """
-        return list(self.data.columns.values)
+        return list(self._data.columns.values)
 
     @property
     def index(self):
         """
         The time index of the data.
         """
-        return self.data.index
+        return self._data.index
+
+    @property
+    def shape(self):
+        """
+        The shape of the data, a tuple (nrows, ncols).
+        """
+        return self._data.shape
 
     @property
     def time_range(self):
         """
         The start and end times of the TimeSeries as a `~sunpy.time.TimeRange`.
         """
-        if len(self.data) > 0:
-            return TimeRange(self.data.index.min(), self.data.index.max())
+        if len(self._data) > 0:
+            return TimeRange(self._data.index.min(), self._data.index.max())
         else:
             return None
 
@@ -165,7 +183,7 @@ class GenericTimeSeries:
         -------
         `~astropy.units.quantity.Quantity`
         """
-        values = self.data[colname].values
+        values = self._data[colname].values
         unit = self.units[colname]
         return u.Quantity(values, unit)
 
@@ -196,12 +214,12 @@ class GenericTimeSeries:
             unit = u.dimensionless_unscaled
 
         # Make a copy of all the TimeSeries components.
-        data = copy.copy(self.data)
+        data = copy.copy(self._data)
         meta = TimeSeriesMetaData(copy.copy(self.meta.metadata))
         units = copy.copy(self.units)
 
         # Add the unit to the units dictionary if already there.
-        if not (colname in self.data.columns):
+        if not (colname in self._data.columns):
             units[colname] = unit
 
         # Convert the given quantity into values for given units if necessary.
@@ -210,12 +228,33 @@ class GenericTimeSeries:
             values = values.to(units[colname]).value
 
         # Update or add the data.
-        if not (colname in self.data.columns) or overwrite:
+        if not (colname in self._data.columns) or overwrite:
             data[colname] = values
 
         # Return a new TimeSeries with the given updated/added column.
         return self.__class__(data, meta, units)
 
+    def remove_column(self, colname):
+        """
+        Remove a column.
+
+        Parameters
+        ----------
+        colname : str
+            The heading of the column to remove.
+
+        Returns
+        -------
+        `sunpy.timeseries.TimeSeries`
+            A new `~sunpy.timeseries.TimeSeries`.
+        """
+        if colname not in self.columns:
+            raise ValueError(f'Given column name ({colname}) not in list of columns {self.columns}')
+        data = self._data.drop(colname, 'columns')
+        units = self.units.copy()
+        units.pop(colname)
+        return self.__class__(data, self.meta, units)
+
     def sort_index(self, **kwargs):
         """
         Returns a sorted version of a `~sunpy.timeseries.TimeSeries`. Generally
@@ -228,7 +267,7 @@ class GenericTimeSeries:
         `~sunpy.timeseries.TimeSeries`
             A new `~sunpy.timeseries.TimeSeries` in ascending chronological order.
         """
-        return GenericTimeSeries(self.data.sort_index(**kwargs),
+        return GenericTimeSeries(self._data.sort_index(**kwargs),
                                  TimeSeriesMetaData(copy.copy(self.meta.metadata)),
                                  copy.copy(self.units))
 
@@ -267,7 +306,7 @@ class GenericTimeSeries:
             end = b
 
         # If an interval integer was given then use in truncation.
-        truncated_data = self.data.sort_index()[start:end:int]
+        truncated_data = self._data.sort_index()[start:end:int]
 
         # Truncate the metadata
         # Check there is data still
@@ -302,10 +341,10 @@ class GenericTimeSeries:
         # if isinstance(self, pandas.Series):
         #    return self
         # else:
-        #    return GenericTimeSeries(self.data[column_name], TimeSeriesMetaData(self.meta.metadata.copy()))
+        #    return GenericTimeSeries(self._data[column_name], TimeSeriesMetaData(self.meta.metadata.copy()))
 
         # Extract column and remove empty rows
-        data = self.data[[column_name]].dropna()
+        data = self._data[[column_name]].dropna()
 
         # Build generic TimeSeries object and sanatise metadata and units.
         object = GenericTimeSeries(data.sort_index(),
@@ -350,7 +389,7 @@ class GenericTimeSeries:
         # Concatenate the metadata and data
         kwargs['sort'] = kwargs.pop('sort', False)
         meta = self.meta.concatenate(otherts.meta)
-        data = pd.concat([self.data.copy(), otherts.data], **kwargs)
+        data = pd.concat([self._data.copy(), otherts.to_dataframe()], **kwargs)
 
         # Add all the new units to the dictionary.
         units = OrderedDict()
@@ -381,18 +420,20 @@ class GenericTimeSeries:
             If provided the image will be plotted on the given axes.
             Defaults to `None`, so the current axes will be used.
         **plot_args : `dict`, optional
-            Any additional plot arguments that should be used when plotting.
+            Additional plot keyword arguments that are handed to
+            :meth:`pandas.DataFrame.plot`.
 
         Returns
         -------
         axes : `~matplotlib.axes.Axes`
             The plot axes.
         """
+        import matplotlib.pyplot as plt
         # Get current axes
         if axes is None:
             axes = plt.gca()
 
-        axes = self.data.plot(ax=axes, **plot_args)
+        axes = self._data.plot(ax=axes, **plot_args)
 
         return axes
 
@@ -408,8 +449,9 @@ class GenericTimeSeries:
         **kwargs : `dict`
             Any additional plot arguments that should be used when plotting.
         """
+        import matplotlib.pyplot as plt
         # Check we have a timeseries valid for plotting
-        self._validate_data_for_ploting()
+        self._validate_data_for_plotting()
 
         # Now make the plot
         figure = plt.figure()
@@ -417,7 +459,7 @@ class GenericTimeSeries:
 
         return figure
 
-    def _validate_data_for_ploting(self):
+    def _validate_data_for_plotting(self):
         """
         Raises an exception if the `~sunpy.timeseries.TimeSeries` is invalid
         for plotting.
@@ -426,9 +468,9 @@ class GenericTimeSeries:
         peek methods.
         """
         # Check we have a valid TS
-        if len(self.data) == 0:
+        if len(self._data) == 0:
             raise ValueError("The timeseries can't be plotted as it has no data present. "
-                             "(len(self.data) == 0)")
+                             "(len(self._data) == 0)")
 
 # #### Miscellaneous #### #
 
@@ -485,14 +527,14 @@ class GenericTimeSeries:
         warnings.simplefilter('always', Warning)
 
         # Populate unspecified units:
-        for column in set(self.data.columns.tolist()) - set(self.units.keys()):
+        for column in set(self._data.columns.tolist()) - set(self.units.keys()):
             # For all columns not present in the units dictionary.
             self.units[column] = u.dimensionless_unscaled
             warnings.warn(f"Unknown units for {column}.", SunpyUserWarning)
 
         # Re-arrange so it's in the same order as the columns and removed unused.
         units = OrderedDict()
-        for column in self.data.columns.tolist():
+        for column in self._data.columns.tolist():
             units.update({column: self.units[column]})
 
         # Now use the amended units Ordered Dictionary
@@ -533,10 +575,10 @@ class GenericTimeSeries:
         """
         # TODO: Table.from_pandas(df) doesn't include the index column. Add request?
         # Get data columns
-        table = Table.from_pandas(self.data)
+        table = Table.from_pandas(self._data)
 
         # Get index column and add to table.
-        index_col = Column(self.data.index.values, name='date')
+        index_col = Column(self._data.index.values, name='date')
         table.add_column(index_col, index=0)
 
         # Add in units.
@@ -556,7 +598,7 @@ class GenericTimeSeries:
         `~pandas.core.frame.DataFrame`
             A `~pandas.core.frame.DataFrame` containing the data.
         """
-        return self.data
+        return self._data
 
     def to_array(self, **kwargs):
         """
@@ -572,10 +614,10 @@ class GenericTimeSeries:
         `~numpy.ndarray`
             If the data is heterogeneous and contains booleans or objects, the result will be of ``dtype=object``.
         """
-        if hasattr(self.data, "to_numpy"):
-            return self.data.to_numpy(**kwargs)
+        if hasattr(self._data, "to_numpy"):
+            return self._data.to_numpy(**kwargs)
         else:
-            return self.data.values
+            return self._data.values
 
     def __eq__(self, other):
         """
@@ -593,7 +635,7 @@ class GenericTimeSeries:
         """
         match = True
         if isinstance(other, type(self)):
-            if ((not self.data.equals(other.data)) or
+            if ((not self._data.equals(other.to_dataframe())) or
                     (self.meta != other.meta) or
                     (self.units != other.units)):
                 match = False
